@@ -27,7 +27,7 @@ logger = logging.getLogger()
 def check_required_fields(required, **args):
     for i in required:
         if args[i] is None:
-            logging.error(' %s parameter not set', i.upper())
+            logger.error(' %s parameter not set', i.upper())
             sys.exit(1)
 
 
@@ -51,10 +51,10 @@ def _print_prs_table(prs, **args):
             pass
         prs_data.append([pr.number, pr.state, status, pr.mergeable_state, pr.base.repo.owner.login, pr.base.ref, pr.head.repo.owner.login, pr.head.ref, pr.title.encode('ascii', errors='ignore')])
     if 'noheaders' in args and args['noheaders']:
-        logging.debug("NO HEADERS")
+        logger.debug("NO HEADERS")
         print tabulate(prs_data, tablefmt=args['tableformat'])
     else:
-        logging.debug("HEADERS - %s", table_headers)
+        logger.debug("HEADERS - %s", table_headers)
         print tabulate(prs_data, headers=table_headers, tablefmt=args['tableformat'])
 
 
@@ -76,7 +76,7 @@ def _load_pr(**args):
     gh = Github(args['token'])
     repo = gh.get_repo(args['repo'])
     pull_request = repo.get_pull(args['number'])
-    logging.debug(" PR: %s", pull_request)
+    logger.debug(" PR: %s", pull_request)
     return pull_request
 
 
@@ -86,7 +86,7 @@ def _load_issue(**args):
     gh = Github(args['token'])
     repo = gh.get_repo(args['repo'])
     issue = repo.get_issue(args['number'])
-    logging.debug(" ISSUE: %s", issue.number)
+    logger.debug(" ISSUE: %s", issue.number)
     return issue
 
 
@@ -96,7 +96,7 @@ def _load_prs_by_branch(**args):
     repo = gh.get_repo(args['repo'])
     prs = [pr for pr in repo.get_pulls() if pr.head.ref == args['head'] and pr.base.ref == args['base']]
     if len(prs) is not 1:
-        logging.error("Probable error, found %s pull(s) from %s -> %s (expected 1)", len(prs), args['head'], args['base'])
+        logger.error("Probable error, found %s pull(s) from %s -> %s (expected 1)", len(prs), args['head'], args['base'])
         _print_prs(prs, **args)
     return prs
 
@@ -115,7 +115,7 @@ def _return_specific_owner_prs(all_prs, filters):
     """
     if _validate_list_of_dict(all_prs):
         owner_prs = [pr for pr in all_prs if filters['owner'] == pr['pr'].user.login]
-        logging.debug("OWNER PRS: %s", [pr['pr'].number for pr in owner_prs])
+        logger.debug("OWNER PRS: %s", [pr['pr'].number for pr in owner_prs])
         return owner_prs
     else:
         return []
@@ -132,7 +132,7 @@ def _return_specific_labeled_prs(all_prs, filters):
             issue = pull_request['issue']
             labels = issue.get_labels()
             matched_labels = [label.name for label in labels if filters['label'] == label.name]
-            logging.debug("MATCHED LABELS: %s", matched_labels)
+            logger.debug("MATCHED LABELS: %s", matched_labels)
             if matched_labels:
                 pr_issue.append({'pr':pull_request['pr'], 'issue':pull_request['issue']})
         return pr_issue
@@ -153,7 +153,7 @@ def _return_specific_status_prs(all_prs, filters):
             if statuses:
                 pr_issue.append({'pr':pull_request['pr'], 'issue':pull_request['issue']})
                 statuses = []
-        logging.debug("SPECIFIC PR STATUSES: %s", [pr['pr'].number for pr in pr_issue])
+        logger.debug("SPECIFIC PR STATUSES: %s", [pr['pr'].number for pr in pr_issue])
         return pr_issue
     else:
         return []
@@ -169,11 +169,11 @@ def _return_specific_comment_prs(all_prs, filters):
         for pull_request in all_prs:
             issue = pull_request['issue']
             comments = issue.get_comments()
-            logging.debug("COMMENTS: %s", [comment.body for comment in comments])
+            logger.debug("COMMENTS: %s", [comment.body for comment in comments])
             matched_comments = [comment.body for comment in comments if re.search(filters['comment'], comment.body)]
             if matched_comments:
                 pr_issue.append({'pr':pull_request['pr'], 'issue':pull_request['issue']})
-        logging.debug("MATCHED COMMENTS: %s", matched_comments)
+        logger.debug("MATCHED COMMENTS: %s", matched_comments)
         return pr_issue
     else:
         return []
@@ -181,6 +181,7 @@ def _return_specific_comment_prs(all_prs, filters):
 
 def _check_approved_mergers(approved_users, comment_users):
     comment_approved_users = [comment_user for comment_user in comment_users if comment_user in approved_users]
+    logger.debug(" APPROVED MERGERS WITH COMMENTS: %s", comment_approved_users)
     if not comment_approved_users:
         raise NoApproversError("No approved mergers were found in comments - Approved mergers: %s " % approved_users)
     else:
@@ -190,6 +191,7 @@ def _check_approved_mergers(approved_users, comment_users):
 def _check_approved_mergers_file(approved_mergers_file, comment_users):
     with open(approved_mergers_file) as approved_mergers_file:
         approved_users = approved_mergers_file.read().splitlines()
+    logger.debug(" APPROVED MERGERS FILE CONTENTS: %s", approved_users)
     return _check_approved_mergers(approved_users, comment_users)
 
 
@@ -226,13 +228,13 @@ def github_check_condition(**args):
     last_commit_time = pytz.utc.localize(datetime.strptime(pr.get_commits().reversed[0].commit.raw_data['committer']['date'], '%Y-%m-%dT%H:%M:%SZ')).astimezone(tz_local)
     issue_comments = issue.get_comments(since=last_commit_time).reversed
     merge_comment_users = [comment.user.login for comment in issue_comments if re.search('.*%s.*' % args['mergecomment'], comment.body) and comment.updated_at == comment.created_at]
-    logging.debug("MERGE COMMENTS %s", [[comment.user.login, comment.body] for comment in issue_comments])
+    logger.debug("MERGE COMMENTS %s", [[comment.user.login, comment.body] for comment in issue_comments])
 
     if not merge_comment_users:
         raise NoMergeCommentError("There are no merge comments associated with this PR")
 
-    logging.debug("PR OWNER: %s", pr.user.login)
-    logging.debug("MERGER: %s", merge_comment_users)
+    logger.debug("PR OWNER: %s", pr.user.login)
+    logger.debug("MERGER: %s", merge_comment_users)
     if args.get('condition_non_owner_merger'):
         merge_comment_users = _check_owner_cannot_ship(pr.user.login, merge_comment_users)
     if args.get('condition_approved_mergers_file'):
@@ -464,6 +466,7 @@ Check conditional status checks
                     help="Logger verbosity: 0 = WARN (default), 1 = INFO, 2 = DEBUG")
 
     args = vars(parser.parse_args())
+    logging.basicConfig(format="%(asctime)s %(levelname)-7s %(filename)20s:%(lineno)-4d | %(message)s")
 
     if args['verbose'] == 0:
         logger.setLevel(logging.WARN) 
